<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>上次检查更新时间：</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>退出内测您将无法获取内测更新</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退 出</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>查看更新日志</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>更新历史记录</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>无更新历史记录</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>系统更新</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>安全更新</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>提供新功能、质量补丁、安全漏洞等全量更新内容</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>提供安全漏洞修复</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>安装时间:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>查看详细信息</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>发布时间：</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>收起</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>版本：</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>更新日志</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>导出至桌面</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>低危</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>中危</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>高危</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>严重</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>严重</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>高危</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>中危</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>低危</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>本次更新修复</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>漏洞</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>漏洞</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1个%2%3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>，</translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>更多详情请访问</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>正在检查更新，请等待…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>您的系统已更新</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>更新包下载失败，请释放%1空间</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>依赖错误，检测更新失败</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>请检查网络后重试</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>更新包下载失败，请检查网络后重试</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>系统无法备份，继续升级，系统将无法回退</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>继续更新，系统将无法回退</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>磁盘空间不足</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg错误</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>部分文件缺失</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>服务连接异常，请检查网络后重试</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>仓库源配置错误，请检查后再试。</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>重新检查更新</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>《隐私政策》</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>使用此软件需要接受软件更新时附带的%1</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>开启更新内容开关，可以获得更优质的功能体验哦</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>当前系统未激活，无法启动更新服务</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>系统已被禁止更新，请联系管理员！</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>系统已开启无忧还原功能，不支持更新，如有疑问请联系企业管理员</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>更新包已下载完毕，请选择您要执行的操作</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>后台静默安装</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>更新并重启</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>更新并关机</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>智能镜像源</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>更新类型</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>功能更新</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>提供新功能、质量补丁、安全漏洞修复等全量更新内容</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>安全更新</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>提供安全漏洞修复</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>第三方来源更新</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>提供额外添加的仓库源更新内容</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>下载限速</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>限速设置</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>自动下载</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>开启“自动下载”，会在联网的情况下自动下载更新包</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>闲时下载</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>开始时间</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>结束时间</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>更新提醒</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>清除软件包缓存</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>历史更新内容</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>内测通道</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>点击此处完成内测申请</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>展开</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>论坛2级及以上用户可加入内测，获取最新更新</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>收起</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>只允许输入1-99999</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>系统更新</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>修复部分已知缺陷和安全漏洞</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>安全更新</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>第三方仓库</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>更新日志</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>日志导出失败，请重试尝试</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>日志已导出至桌面</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>系统更新</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>系统更新升级</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>更新设置</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>正在安装</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>更新下载完成</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>安装更新</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>更新大小：</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>更新下载失败</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>下载更新中...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>下载中</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>可设置系統更新、安全更新、闲时更新、更新提醒等</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>立即重启</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下 载</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>正在安装更新...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>重 试</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>继续更新</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>检测到有可用的更新</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>安装更新失败</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>为了您能够正常使用系统和应用，更新后请重启电脑</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>正在备份...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>正在备份</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>备份失败</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>更新安装成功</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>继续更新，系统将无法回退</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>重试</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>继续更新</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>电池电量低于60%，为保障更新成功，请及时接入电源</translation>
    </message>
</context>
</TS>